# Guavacado Web Server

A python library for dynamic, as well as static, web content. 

Originally written as a wrapper for [CherryPy](https://cherrypy.org/), and later the native Python [http.server](https://docs.python.org/3/library/http.server.html), but has evolved to be an independent library, instead implemented on raw [socket](https://docs.python.org/3/library/socket.html)s.
